from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("ses_sns_tracker", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="sesmaildelivery",
            options={"verbose_name": "SES Mail Delivery", "verbose_name_plural": "SES Mail Deliveries"},
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-22 09:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("ses_sns_tracker", "0003_auto_20220322_0945"),
    ]

    operations = [
        migrations.AlterField(
            model_name="sesmaildelivery",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
    ]



# Generated by Django 3.2.12 on 2022-03-22 09:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("ses_sns_tracker", "0002_alter_sesmaildelivery_options"),
    ]

    operations = [
        migrations.AlterField(
            model_name="sesmaildelivery",
            name="mail_data",
            field=models.JSONField(blank=True, default=dict, help_text="Amazon SNS mail data"),
        ),
        migrations.AlterField(
            model_name="sesmaildelivery",
            name="state_data",
            field=models.JSONField(
                blank=True, default=dict, help_text="Amazon SNS event data (bounce/complaint/delivery object)"
            ),
        ),
    ]



from django_ses.views import SESEventWebhookView
from typing_extensions import deprecated


@deprecated("Use SESEventWebhookView instead")
class SESSNSTrackerWebhookView(SESEventWebhookView):
    """Deprecated. Use SESEventWebhookView directly instead."""



from django.contrib import admin

from .models import SESMailDelivery


@admin.register(SESMailDelivery)
class SESMailDeliveryAdmin(admin.ModelAdmin):
    list_display = ("recipient", "sent_at", "updated_at", "state")
    list_filter = ("state",)
    readonly_fields = ("sent_at", "updated_at")
    ordering = ("-updated_at",)



from django.apps import AppConfig


class SESSNSTrackerConfig(AppConfig):
    name = "ses_sns_tracker"
    verbose_name = "SES/SNS Tracker"
    default_auto_field = "django.db.models.BigAutoField"

    def ready(self):
        from . import signals  # NOQA



from django.urls import path

from django_ses.views import SESEventWebhookView


"""
URLConf left for compatibility. New setups should use the view directly in their own URLConf.
"""

app_name = "ses_sns_tracker"

urlpatterns = [
    path("bounce/", SESEventWebhookView.as_view(), name="handle-event-webhook"),
]



# Generated by Django 1.11.20 on 2019-05-21 11:22

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="SESMailDelivery",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("recipient", models.EmailField(max_length=254)),
                ("message_id", models.CharField(max_length=128)),
                ("request_id", models.CharField(max_length=128)),
                (
                    "state",
                    models.PositiveSmallIntegerField(
                        choices=[(0, "Sent"), (1, "Delivered"), (2, "Bounced"), (3, "Complaint")], default=0
                    ),
                ),
                (
                    "state_data",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, default=dict, help_text="Amazon SNS event data (bounce/complaint/delivery object)"
                    ),
                ),
                (
                    "mail_data",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        blank=True, default=dict, help_text="Amazon SNS mail data"
                    ),
                ),
                ("sent_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "ordering": ("-updated_at",),
                "verbose_name": "SES Mail Delivery",
                "verbose_name_plural": "SES Mail Deliveries",
            },
        ),
    ]
